Module wad

Module wad 

Doom WADs and other WAD-like formats. Right now only Doom wads.

Structs

DoomWad
A wad file. Contains game data for games in the doom engine family.
QuakePack
A quake .PAK file. Contains game data for Quake as well as games in the GoldSrc family of engines (todo can someone verify? -nf)
QuakeWad
Quake’s “Wad2” format.

Enums

DoomWadFlavor
The “flavor” of a wad file, being either an IWAD intended to hold main game files or a PWAD intended to hold modded/additional content.