A rust crate for parsing Doom engine WAD files.
Where’s All the Data? It’s in the WAD struct.
Modules
- agnostic
- Format-agnostic traits. These are implemented by specific formats to provide standard functionality for each.
- error
- Error type(s) specific to this crate, for use within the other functions this crate
- lump
- Doom wad lumps and other lumpy formats. Right now just the classic doom lumps.
- wad
- Doom WADs and other WAD-like formats. Right now only Doom wads.