Crate caco

Crate caco 

A rust crate for parsing Doom engine WAD files.

Where’s All the Data? It’s in the Wad struct.

Re-exports

pub use wad::Wad;
pub use wad::Lump;
pub use lumps::LumpSeries;
pub use lumps::LumpSeriesMut;

Modules

lumps
Traits to be implemented for lumpy things. For now these just provide functionality to Wads but I figure other formats might be implemented at some point (pk3?? idk) where this abstraction could be useful.
wad
Wad data structure stuff lives here… and thats pretty much it. These modules are more for file structure!